searchNodes=[{"ref":"EtsLock.html","title":"EtsLock","type":"module","doc":"EtsLock is a library for acquiring exclusive locks on data in ETS tables. Using with_ets_lock/4, you can process all {key, value} tuples for a given key while being sure other processes using with_ets_lock/4 are not mutating the data stored for this key. Processing is performed in a separate process so that an execution timeout (:exec_timeout) can be enforced. For high concurrent performance, all locks are stored in a separate ETS table, and no GenServers or other processes are used to coordinate access. This is in contrast to the erlang-ets-lock library, which uses a single GenServer to serialize access to ETS."},{"ref":"EtsLock.html#with_ets_lock/4","title":"EtsLock.with_ets_lock/4","type":"function","doc":"Locks a key in ETS and invokes fun on the {key, value} tuples for that key. Returns {:ok, fun.(tuples)} on success. If the key is already locked, this function spins until the lock is released or the :wait_timeout is reached. Example: iex&gt; table = :ets.new(:whatever, [:set, :public]) iex&gt; spawn(fn -&gt; ...&gt; ## Wait 50ms, try to acquire lock, then insert ...&gt; Process.sleep(50) ...&gt; EtsLock.with_ets_lock(table, :key, fn _ -&gt; ...&gt; :ets.insert(table, {:key, :yup}) ...&gt; end) ...&gt; end) iex&gt; spawn(fn -&gt; ...&gt; ## Acquire lock immediately, hold it for 100ms, then insert ...&gt; EtsLock.with_ets_lock(table, :key, fn _ -&gt; ...&gt; Process.sleep(100) ...&gt; :ets.insert(table, {:key, :nope}) ...&gt; end) ...&gt; end) iex&gt; Process.sleep(200) iex&gt; :ets.lookup(table, :key) [{:key, :yup}] Options: :wait_timeout - Milliseconds to wait when acquiring a lock. Default 5000. Set to :infinity to try forever to acquire a lock. :exec_timeout - Milliseconds to allow fun to hold the lock before its execution is cancelled and the lock is released. Default 5000. Set to :infinity to hold the lock indefinitely until fun has finished. :fail_timeout - Milliseconds to wait before forcibly deleting a lock after it should have been released, but wasn&#39;t. Default 1000. Provides protection against permanently hanging locks in the case that both the caller and the spawned task crash. Set to :infinity to disable this protection (not recommended). :spin_delay - Milliseconds to wait between every attempt to acquire a lock. Default 2. :lock_table - ETS table in which to store locks. Default EtsLock.Locks."},{"ref":"EtsLock.html#t:error_reason/0","title":"EtsLock.error_reason/0","type":"type","doc":""},{"ref":"EtsLock.html#t:key/0","title":"EtsLock.key/0","type":"type","doc":""},{"ref":"EtsLock.html#t:option/0","title":"EtsLock.option/0","type":"type","doc":""},{"ref":"EtsLock.html#t:opts/0","title":"EtsLock.opts/0","type":"type","doc":""},{"ref":"EtsLock.html#t:value/0","title":"EtsLock.value/0","type":"type","doc":""}]